@@ -1,5 +1,6 @@
 """
 Input output utilities
+TODO: look at https://github.com/marian-code/ssh-utilities !!!
 """
 import os
 import shutil
@@ -68,6 +69,14 @@ def resolve(path, *joins):
     return path
 
 
+def extension(path: str) -> str:
+    """
+    Returns:
+        Extension of the path
+    """
+    return Path(path).suffix.lstrip(".")
+
+
 def cp(source, dest, overwrite=True):  # pylint: disable=invalid-name
     """
     copy with shutil
@@ -107,7 +116,7 @@ def mv(source, dest, overwrite=True):  # pylint: disable=invalid-name
             "Attempting to move to already existing destination"
             " path {0}.".format(dest)
         )
-    logging.info("Moving file or dir %s to %s", source, dest)
+    logging.debug("Moving file or dir %s to %s", source, dest)
     if os.path.isfile(source):
         shutil.move(source, dest)
     elif os.path.isdir(source):
@@ -155,12 +164,12 @@ def cd_tmp(tmp_path):
         cd(cwd)
 
 
-def ls(directory=".", **kwargs):  # pylint: disable=invalid-name
+def ls(directory=".", *joins, **kwargs):  # pylint: disable=invalid-name
     """
     a bash ls imitation.
     allows wildcards
     """
-    directory = resolve(directory)
+    directory = resolve(directory, *joins)
     if os.path.isdir(directory):
         directory = os.path.join(directory, "*")
     return [os.path.basename(p) for p in glob.iglob(directory, **kwargs)]
@@ -183,10 +192,10 @@ def mkdir(path, is_dir=False):
     else:
         directory = os.path.dirname(path)
     if not os.path.exists(directory) and not directory == "":
-        logging.info("Create directory %s", directory)
+        logging.debug("Create directory %s", directory)
         os.makedirs(directory)
     else:
-        logging.warning("Directory %s already exists", directory)
+        logging.debug("Directory %s already exists", directory)
 
 
 def tree(directory):
