@@ -10,6 +10,7 @@ import functools
 import matplotlib as mpl
 import matplotlib.pyplot as plt
 import matplotlib.animation as manimation
+import matplotlib.collections as mcollections
 import matplotlib.dates as dates
 import matplotlib.patches as mplpatch
 import mpl_toolkits.mplot3d as plt3d
@@ -642,6 +643,47 @@ class ApiBackendMatplotlib(rna.plotting.ApiBackend):
             raise NotImplementedError("Only Scalars and Vectors implemented")
         return artists
 
+    @rna.plotting.plot_signature
+    def plot_tensor_map(self, axes, tensors, map_, **kwargs):
+        """
+        Args:
+            tensors: np.ndarray
+            map_: indices of the tensors to connect to a graph
+
+        Examples:
+            >>> import rna
+            >>> import tfields
+            >>> tm = tfields.TensorMaps(
+            ...     [[0, 0, 0], [0, 1, 0], [1, 0, 0], [1, 1, 0], [0.5, 0.5, 0]]
+            ... )
+            >>> tm.maps[2] = tfields.Tensors([[0, 1], [0, 2], [1, 3], [2, 3]])
+            >>> artist = tm.plot(map=2, dim=2, color="r", linewidths=4)
+            >>> rna.plotting.show()
+        """
+        x_index, y_index, z_index = self.pop_xyz_index(kwargs)
+        tensors = np.array(tensors)
+        map_ = np.array(map_)
+        if map_.shape[0] == 0:
+            logging.warning("No map to plot")
+            return None
+        if max(map_.flat) > tensors.shape[0]:
+            raise ValueError("Some indices point to non existing tensors.")
+
+        dim = self.axes_dim(axes)
+        if dim == 2:
+            color = self.retrieve(
+                kwargs, "edgecolor", "color", default=None, keep=False
+            )
+            if color is not None:
+                kwargs["edgecolor"] = color
+            tensors = np.transpose([tensors[:, x_index], tensors[:, y_index]])
+            lines = np.array([tensors[edge] for edge in map_])
+            artist = mcollections.LineCollection(lines, **kwargs)
+            axes.add_collection(artist)
+        else:
+            raise NotImplementedError("")
+        return artist
+
     @rna.plotting.plot_signature
     def plot_mesh(self, axes, vertices, faces, **kwargs):
         """
