@@ -324,6 +324,9 @@ def color_cycle(cmap=None, n=None):
     if cmap:
         if n is None:
             raise AttributeError("color_cycle with cmap requires n")
+        if n == 0:
+            # At least give one color (easier to debug)
+            n = 1
         colors = to_colors(np.linspace(0, 1, n), cmap=cmap, vmin=0, vmax=1, fmt="hex")
     else:
         colors = list([color["color"] for color in mpl.rcParams["axes.prop_cycle"]])
