@@ -84,13 +84,6 @@ class PlotKwargsFunctions:
     This provides a standardized signature of plotting functions.
     """
 
-    @staticmethod
-    def set(kwargs, attr, value):
-        """
-        Set attribute with value to kwargs
-        """
-        kwargs.kwargs[attr] = value
-
     @staticmethod
     def retrieve(
         kwargs: dict,
@@ -418,10 +411,10 @@ class Api(
     STRATEGY_TYPE = ApiBackend
     STRATEGY_DEFAULT = "matplotlib"
 
-    def __init__(self):
+    def __init__(self, data=None):
         # Make sure you pass nothing to backend
         super().__init__()
-        self.data = None
+        self.data = data
 
     def plot(self, data=None, **kwargs):
         """
